@@ -171,6 +171,8 @@ class ObjectConfig:
 			self.typeCategory = 'bool'
 		elif firstTypeDigit in ['5', '6', '7', '8', '9', '12', '13']:
 			if self.type in ['5.001', '5.003', '9.xxx']:
+				# 5.001 and 5.003 are actually float values encoded on 256
+				# levels between 0-100 or 0-360.
 				self.typeCategory='float'
 			else:
 				self.typeCategory = 'int'
@@ -235,7 +237,7 @@ class Object(object):
 	@property
 	def type(self):
 		""" Return the string corresponding to the type attribute in XML configuration. """
-		self._objectConfig.type
+		return self._objectConfig.type
 
 	@property
 	def value(self):
@@ -263,6 +265,8 @@ class Object(object):
 			return valueStr in ['on', '1']
 		elif self._objectConfig.typeCategory == 'int':
 			return int(valueStr)
+		elif self._objectConfig.typeCategory == 'float':
+			return float(valueStr)
 		else:
 			return valueStr
 
