@@ -37,7 +37,7 @@ logHandlers = []
 stdOutLog = None # None to disable stdout logging, otherwise log level.
 fileLog = None # Tuple (filename, level)
 
-def initLogger(fileLogInfo=None, stdoutLogLevel=logging.INFO):
+def initLogger(fileLogInfo=None, stdoutLogLevel=logging.INFO, usesDetailedLogging=True):
 	"""
 	Initialize the logging system. Should be called prior to any other function of this module.
 
@@ -50,7 +50,7 @@ def initLogger(fileLogInfo=None, stdoutLogLevel=logging.INFO):
 	global logLevel
 
 	_setHandlers(None, None)
-	_setHandlers(fileLogInfo, stdoutLogLevel)
+	_setHandlers(fileLogInfo, stdoutLogLevel, usesDetailedLogging)
 	logging.getLogger().setLevel(logging.DEBUG)
 	signal.signal(signal.SIGUSR1, _usr1SignalHandler)
 	reportDebug('Logger initialized.')
@@ -69,7 +69,7 @@ def parseLevel(levelToString):
 	else:
 		raise Exception('Unknown verbosity level ' + levelToString)
 
-def _setHandlers(fileLogInfo, stdoutLogLevel):
+def _setHandlers(fileLogInfo, stdoutLogLevel, usesDetailedLogging=True):
 	global logHandlers
 	global fileLog
 	global stdOutLogLevel
@@ -89,16 +89,19 @@ def _setHandlers(fileLogInfo, stdoutLogLevel):
 	# Create new handlers.
 	logHandlers = []
 	if not fileLog is None:
-		_addHandler(logging.FileHandler(fileLog[0]), fileLog[1])
+		_addHandler(logging.FileHandler(fileLog[0]), fileLog[1], usesDetailedLogging)
 	if not stdoutLogLevel is None:
-		_addHandler(logging.StreamHandler(), stdoutLogLevel)
+		_addHandler(logging.StreamHandler(), stdoutLogLevel, usesDetailedLogging)
 
-def _addHandler(handler, logLevel):
+def _addHandler(handler, logLevel, usesDetailedLogging=True):
 	global logHandlers
 
 	handler.setLevel(logLevel)
 	logHandlers.append(handler)
-	formatter = logging.Formatter('%(asctime)s [%(levelname)s] [%(threadName)s] [%(callerfilename)s:%(callerlineno)d] %(message)s')
+	if usesDetailedLogging:
+		formatter = logging.Formatter('%(asctime)s [%(levelname)s] [%(threadName)s] [%(callerfilename)s:%(callerlineno)d] %(message)s')
+	else:
+		formatter = logging.Formatter('%(message)s')
 	handler.setFormatter(formatter)
 	logging.getLogger().addHandler(handler)
 
